/*******************************************************************************
* File Name: SW_PUSHBUTTON.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "SW_PUSHBUTTON.h"


/*******************************************************************************
* Function Name: SW_PUSHBUTTON_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void SW_PUSHBUTTON_Write(uint8 value) 
{
    uint8 staticBits = SW_PUSHBUTTON_DR & ~SW_PUSHBUTTON_MASK;
    SW_PUSHBUTTON_DR = staticBits | ((value << SW_PUSHBUTTON_SHIFT) & SW_PUSHBUTTON_MASK);
}


/*******************************************************************************
* Function Name: SW_PUSHBUTTON_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void SW_PUSHBUTTON_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(SW_PUSHBUTTON_0, mode);
}


/*******************************************************************************
* Function Name: SW_PUSHBUTTON_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SW_PUSHBUTTON_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SW_PUSHBUTTON_Read(void) 
{
    return (SW_PUSHBUTTON_PS & SW_PUSHBUTTON_MASK) >> SW_PUSHBUTTON_SHIFT;
}


/*******************************************************************************
* Function Name: SW_PUSHBUTTON_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SW_PUSHBUTTON_ReadDataReg(void) 
{
    return (SW_PUSHBUTTON_DR & SW_PUSHBUTTON_MASK) >> SW_PUSHBUTTON_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SW_PUSHBUTTON_INTSTAT) 

    /*******************************************************************************
    * Function Name: SW_PUSHBUTTON_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SW_PUSHBUTTON_ClearInterrupt(void) 
    {
        return (SW_PUSHBUTTON_INTSTAT & SW_PUSHBUTTON_MASK) >> SW_PUSHBUTTON_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
