/*******************************************************************************
* File Name: SleepTimer.h
* Version .
*
*  Description:
*     This file provides constants and parameter values for the Sleep Timer
*     Component.
*
*   Note:
*
********************************************************************************
* Copyright 2008-2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/


#include "cytypes.h"
#include "cydevice_trm.h"

#if !defined(SleepTimer_H)
#define SleepTimer_H


/**************************************
 *  Function Prototypes
 *************************************/

void  SleepTimer_Start(void);
void  SleepTimer_Stop(void);
void  SleepTimer_EnableInt(void);
void  SleepTimer_DisableInt(void);
void  SleepTimer_SetInterval(uint8 interval);
uint8 SleepTimer_GetStatus(void);


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Types SLEEPTIMER_interval_enum, Used in parameter Interval*/
#define SleepTimer__CTW_2_MS 1
#define SleepTimer__CTW_4_MS 2
#define SleepTimer__CTW_8_MS 3
#define SleepTimer__CTW_16_MS 4
#define SleepTimer__CTW_32_MS 5
#define SleepTimer__CTW_64_MS 6
#define SleepTimer__CTW_128_MS 7
#define SleepTimer__CTW_256_MS 8
#define SleepTimer__CTW_512_MS 9
#define SleepTimer__CTW_1024_MS 10
#define SleepTimer__CTW_2048_MS 11
#define SleepTimer__CTW_4096_MS 12


/***************************************
* API Constants
***************************************/

#define SleepTimer_INTERRUPT_CHNG_BIT 0x01u
#define SleepTimer_INTERVAL_CHNG_BIT  0x02u


/***************************************
 *  Initialization Values
 **************************************/

#define SleepTimer_ENABLE_INTERRUPT    0
#define SleepTimer_INTERVAL            10


/**************************************
 *  Registers
 *************************************/

#define SleepTimer_CTW_INTERVAL       (* (reg8 *) CYREG_PM_TW_CFG1 )
#define SleepTimer_CTW_INTERVAL_PTR   (  (reg8 *) CYREG_PM_TW_CFG1 )

#define SleepTimer_TW_CFG             (* (reg8 *) CYREG_PM_TW_CFG2 )
#define SleepTimer_TW_CFG_PTR         (  (reg8 *) CYREG_PM_TW_CFG2 )

#define SleepTimer_WDT_CFG            (* (reg8 *) CYREG_PM_WDT_CFG )
#define SleepTimer_WDT_CFG_PTR        (  (reg8 *) CYREG_PM_WDT_CFG )

#define SleepTimer_ILO_CFG            (* (reg8 *) CYDEV_SLOWCLK_BASE )
#define SleepTimer_ILO_CFG_PTR        (  (reg8 *) CYDEV_SLOWCLK_BASE )

#define SleepTimer_INT_SR             (* (reg8 *) CYREG_PM_INT_SR )
#define SleepTimer_INT_SR_PTR         (  (reg8 *) CYREG_PM_INT_SR )


/**************************************
 *  Register Constants
 *************************************/

/* Issue interrupt when CTW enabled */
#define SleepTimer_CTW_IE        0x08u
/* CTW enable */
#define SleepTimer_CTW_EN        0x04u
/* Watch dog reset enable */
#define SleepTimer_WDR_EN        0x10u
/* CTW reset */
#define SleepTimer_CTW_RESET     0x80u
/* 1 kHz ILO  */
#define SleepTimer_ILO_1KHZ_EN   0x02u
/* CTW interval mask  */
#define SleepTimer_INTERVAL_MASK 0x0Fu

/* Device has moved from limited active to active mode */
#define SleepTimer_PM_INT_SR_REACT    0x80u
/* A limited active ready event has occured */
#define SleepTimer_PM_INT_SR_LIMACT   0x08u
/* A onepps event has occured */
#define SleepTimer_PM_INT_SR_ONEPPSP  0x04u
/* A central timewheel event has occured */
#define SleepTimer_PM_INT_SR_CTW      0x02u
/* A fast timewheel event has occured */
#define SleepTimer_PM_INT_SR_FTW      0x01u

#endif  /* SleepTimer_H */


/* [] END OF FILE */
